 
/************************************************************************
 *
 * Created with Falch.net DeveloperStudio
 * http://www.falch.net/
 * 
 * File : main.c
 * 
 * Description :  
 *
 * History:
 *			Name		Date					Description
 *			----		----					-----------
 *			default	2/28/2004 1:36:23 PM		Created

 *
 ***********************************************************************/
 

#include <PalmOS.h>
#include "RomanRoad.hpp"
#include "RomanRoad_res.hpp"
//#include "CommonUtils.cpp"

/***********************************************************************
 *
 * FUNCTION:	StartApplication
 *
 * DESCRIPTION:	This routine will launch the application's main form
 *
 * PARAMETERS:	 none
 *					
 * RETURNED:	 returns nothing
 *
 * REVISION HISTORY:
 *			Name		Date					Description
 *			----		----					-----------
 *			default	2/28/2004 1:36:23 PM		Created

 * 
 ***********************************************************************/

static int StartApplication(void)
{
	FrmGotoForm(frmMain);
//	GblVerseIndex = 0;
	return 0;
}


/***********************************************************************
 *
 * FUNCTION:	ApplicationHandleEvent
 *
 * DESCRIPTION:	This routine is called from the event loop, and its
 *				main responsibility is to load forms and set form
 *				eventhandlers.
 *
 * PARAMETERS:	 EventPtr	event	Pointer to the event
 *					
 * RETURNED:	 handled/not handled
 *
 * REVISION HISTORY:
 *			Name		Date					Description
 *			----		----					-----------
 *			default	2/28/2004 1:36:23 PM		Created

 * 
 ***********************************************************************/

static Boolean ApplicationHandleEvent(EventPtr event)
{
	UInt16 formID;
	FormPtr form;
	Boolean handled = false;
	
	// Application event loop
	switch (event->eType)
	{
		case frmLoadEvent:
			// Handle form load events
			formID = event->data.frmLoad.formID;
			form = FrmInitForm(formID);
			FrmSetActiveForm(form);		

			switch (formID)
			{
				case frmMain:
					// Set event handler for frmMain
					FrmSetEventHandler(form, (FormEventHandlerPtr) frmMain_HandleEvent);
					break;
				default:
					break;
			}
			handled = true;
			break;
		default:
			break;
	}

	return handled;
}


/***********************************************************************
 *
 * FUNCTION:	EventLoop
 *
 * DESCRIPTION:	The eventloop polls the event que for new events and
 *				dispatches them to the different event handlers.
 *
 * PARAMETERS:	 Nothing
 *					
 * RETURNED:	 Nothing
 *
 * REVISION HISTORY:
 *			Name		Date					Description
 *			----		----					-----------
 *			default	2/28/2004 1:36:23 PM		Created

 * 
 ***********************************************************************/

static void EventLoop(void)
{
	Err error;
	EventType event;

	// Main event loop
	do
	{
		// Get next event
		EvtGetEvent(&event, evtWaitForever);
	
		// Handle event
		if (!SysHandleEvent(&event))
		{
			if (!MenuHandleEvent(0, &event, &error))
			{
				if (!ApplicationHandleEvent(&event))
					FrmDispatchEvent(&event);	
			}
		}
	}
	while (event.eType != appStopEvent);
}


/***********************************************************************
 *
 * FUNCTION:	StopApplication
 *
 * DESCRIPTION:	this routine closes all open forms by calling 
 *				FrmCloseAllForms()
 *
 * PARAMETERS:	 Nothing
 *					
 * RETURNED:	 Nothing
 *
 * REVISION HISTORY:
 *			Name		Date					Description
 *			----		----					-----------
 *			default	2/28/2004 1:36:23 PM		Created

 * 
 ***********************************************************************/

static void StopApplication(void)
{
	// Insert stop code here
	FrmCloseAllForms();
}


/***********************************************************************
 *
 * FUNCTION:	PilotMain
 *
 * DESCRIPTION:	Main entrypoint for the application
 *
 * PARAMETERS:	cmd			Application Launchcode
 *				cmbBPB		Pointer to a structure that is 
 *							associated with the launch code. 		
 *				launchFlags	value providing extra information about 
 *							the launch
 *					
 * RETURNED:	Result of the launch
 *
 * REVISION HISTORY:
 *			Name		Date					Description
 *			----		----					-----------
 *			default	2/28/2004 1:36:23 PM		Created

 * 
 ***********************************************************************/

UInt32 PilotMain(UInt16 cmd, void *cmdPBP, UInt16 launchFlags)
{
	Err error;
	
	switch (cmd) 
 	{
		case sysAppLaunchCmdNormalLaunch:
			// Application start code
			error = StartApplication();
			if (error)
				return error;
		
			// Maintain event loop
			EventLoop();

			// Stop application 
			StopApplication();		
			break;
		default:
			break;

	}

	return 0;
}

